@@ -542,10 +542,11 @@ class Unexpected(Macro):
     def run(self, ngrams: Ngrams, vars: Dict[str, Any], args: List[Any]):
         if self.question_natex.match(ngrams.text()):
             if '_explained_stupidity_' in vars and vars['_explained_stupidity_'] == 'True':
-                vars['__response_prefix__'] = 'Placeholder I don\'t understand'
+                vars['__response_prefix__'] = 'I\'m not really sure at the moment.'
             else:
                 vars['_explained_stupidity_'] = 'True'
-                vars['__response_prefix__'] = 'Placeholder I don\'t know'
+                vars['__response_prefix__'] = 'Sorry, I don\'t think I understand your question. ' \
+                                              'There\'s still a lot I\'m trying to figure out. '
         else:
             vars['__response_prefix__'] = 'Yeah.'
         return True
