@@ -7,39 +7,31 @@ cv = ChatFlow(os.path.join('modules','common.json'))
 system_loop = {
     'state': 'sr',
 
-    '#GATE()'
-    '"I\'ve been really worried about the corona virus lately. Have you been keeping up on it?"': {
+    '#GATE(focus:news) '
+    '"So what do you think, is the corona virus outbreak a disaster? '
+    'Or is the virus something people shouldn\'t be too worried about?"': {
         'score': 100,
-        'error': 'ur',
-        natexes.disagree:{
-            '#SET($informed=False)'
-            '"I don\'t mean to scare you, but it\'s worth reading up on."': {'score': 0.5, 'state': 'sr'}
-        }
-    },
-
-    '#GATE()'
-    '"I noticed there\'s a huge range of opinions on the severity of the virus. '
-    'What do you think? Is it going to be a big disaster? '
-    'Or is the virus something people shouldn\'t be too worried about?"': {
         'error': 'ur',
         '[!-{} {}]'.format(natexes.negation,
-        '[{#ONTE(negative), [all, die], disaster}]'): {
-            '#SET($serious=True)'
+        '[{#ONTE(negative), [all, die], disaster, apocalypse}]'): {
+            '#SET($affected=True)'
             '"Sounds like you\'re really taking it seriously."': 'sr'
         },
-        '<{} {}>'.format(natexes.negation,
+        '<{} {}>'.format('{' + natexes.negation + ', too, overly, overboard}',
         '[{#ONTE(negative), [all, die]}]'): {
+            'score': 2.0,
             '#SET($serious=False)'
             '#SET($focus=closings)'
             '"You\'re probably right. '
-            'But, the virus is already impacting the economy and lots of things are shutting down."': 'ur'
+            'But, the virus is hugely impacting the economy and lots of things are shutting down."': 'ur'
 
         }
     },
 
-    '#GATE()'
-    '"I heard there are over" #KBE(corona virus, number_cases) "confirmed cases. '
+    '#GATE() #ANY($focus=area, $focus=None) #SET($focus=area)'
+    '"You know, I heard there are over" #KBE(corona virus, number_cases) "confirmed cases of the virus. '
     'It\'s really becoming a worldwide disease. Are you in an area that\'s highly affected?"': {
+        'score': 100,
         'error': 'ur',
         '#SET($affected=True)' + natexes.agree:{
             '"Uh oh. Well I hope you\'re staying healthy."': 'sr'
@@ -49,7 +41,7 @@ system_loop = {
         }
     },
 
-    '#GATE()'
+    '#GATE(focus:area, supplies:None)'
     'You know, I hear the grocery stores in affected areas have lots of empty shelves right now.'
     '"I\'m not sure how necessary it is, but have you been stocking up on supplies?"':{
         'error': 'ur',
@@ -57,8 +49,7 @@ system_loop = {
             '"I guess you can never be too prepared."': 'sr'
         },
         '[{%s, [%s necessary]}]' % (natexes.disagree, natexes.negation):{
-            '"Some people have been going a little overboard on the amount of supplies they are buying, '
-            'but you should make sure to have enough of the essentials."': 'ur'
+            '"Some people have been going a little overboard on the amount of supplies they are buying, right?."': 'ur'
         },
         '[{overreacting, overreact, #ONTE(negative_appraisal), no reason, [!dont, need]}]':{
             '"Yeah, it\'s pretty crazy out there."': 'ur'
@@ -77,13 +68,13 @@ system_loop = {
         'error': 'ur'
     },
 
-    '#GATE(sick:None)'
+    '#GATE(sick:None) #ANY($focus=news, $focus=None) '
     '"Do you know anyone who is sick right now?"': {
         'error': 'ur',
         '[{%s my}]' % natexes.agree: {
             '"Oh no, that\'s awful. I hope they recover soon."': 'ur'
         },
-        '[me]':{
+        '[!-%s [me]]' % natexes.negation:{
             'score': 1.1,
             '"Oh no, I\'m sorry you don\'t feel well. '
             'I hope you\'re taking care of yourself. '
@@ -95,10 +86,11 @@ system_loop = {
         }
     },
 
-    '#GATE()'
-    '"My friend\'s grandma is on her way back from a road trip to Florida right now. '
-    'I think she\'ll make it back safely, but I worry about her traveling and staying in hotels right now. '
+    '#GATE() #ANY($focus=travel, $focus=None) #SET($focus=news) '
+    '"So my friend\'s grandma is on her way back from a road trip to Florida right now. '
+    'I think she\'ll make it back alright, but I worry about her traveling and staying in hotels right now because of the virus. '
     'Is anyone you know travelling?"': {
+        'score': 100,
         'error': 'ur',
         '[{' + natexes.agree + 'my, i have a}]': {
             '"Well tell them to stay safe."': 'sr'
@@ -128,9 +120,10 @@ system_loop = {
         'state': 'ur'
     },
 
-    '#GATE()'
-    '#SET($focus=closings)'
+    '#GATE() #ANY($focus=closings, $focus=None)'
+    '#SET($focus=area)'
     '"Can you believe how many things are shutting down right now?"':{
+        'score': 100,
         'error': 'ur',
         '[#ONT(school)]':{
             '"Yeah schools closing is tough, but probably necessary. '
@@ -159,12 +152,12 @@ user_loop = {
     'state': 'ur',
 
     '#SET($sick=related)'
-    '[{my} {sick, ill, infected, virus, hospital, fever}]':{
+    '[!' + natexes.negation + '[{my} {sick, ill, infected, virus, hospital, fever}]]':{
         '"Oh no, that\'s awful. I hope they recover soon."': 'ur'
     },
 
     '#SET($sick=user)'
-    '[{i, im} {sick, ill, infected, virus, fever}]': {
+    '[!' + natexes.negation + '[{i, im} {sick, ill, infected, virus, fever}]]': {
         '"Oh no, I\'m sorry you don\'t feel well. '
         'I hope you\'re taking care of yourself. '
         'Drink lots of water and please get help if you need it, '
@@ -183,25 +176,36 @@ user_loop = {
     '[{what, {shutting, down, closing, suspending, closed, suspended}}]':{
         'score': 0.9,
 
-        '#SET($focus=closings)'
+        '#SET($focus=area)'
         '"Lots of schools are being closed, including most universities. '
         'Lots of people are also being encouraged to work remotely, if it\'s possible."': 'ur'
     },
 
-    '#SET($focus=closings)'
+    '#SET($focus=area)'
     '[{shutting, down, closing, suspending, closed, suspended}]':{
         'score': 0.8,
 
         '"Yeah, lots of things are being shut down."': 'sr'
     },
 
-    '#SET($focus=closings)'
+    '<{#ONTE(negative) "can\'t", "going", "go"} {store, grocery, groceries, food, shop, shopping, mall, market}>':{
+        '"Going and getting things can be tough right now for sure. "': 'sr'
+    },
+
+    '{social distancing, social distance, '
+    '[{[i, {feel, feeling, like, am}], "i\'m"} #ONTE(negative_emotion)] '
+    '[{i, "i\'m", staying, at, stay, stuck, trapped} {home, my house, my apartment, my condo}]}':{
+        '"I understand. You know, you should do video chat with your friends and family. '
+        'My friends are doing it all the time and they say it really helps."': 'ur'
+    },
+
+    '#SET($focus=area)'
     '<{shutting, down, closing} #ONT(school)>':{
 
         '"Yeah, that must have been a tough decision to close schools."': 'ur'
     },
 
-    '#SET($focus=closings)'
+    '#SET($focus=area)'
     '<{shutting, down, closing, suspending, closed, suspended} {#ONT(sports), stadiums}>':{
 
         '"Right. I\'m going to miss watching basketball games now that the NBA is suspended."': 'ur'
@@ -230,16 +234,24 @@ user_loop = {
         '"Nobody close to me is infected, but I have talked to some people who know someone who\'s sick"': 'sr'
     },
 
+    '#SET($focus=area)'
     '[{work, job, working, i am} {remote, remotely, from home}]':{
         '"Working remotely is really smart right now, at least for the next few weeks."': 'sr'
     },
 
+    '#SET($focus=area) '
+    '[' + natexes.negation + ' {work, office, school, job}]':{
+        '"The virus is making things hard. Lots of people can\'t go in to work or school."': 'sr'
+    },
+
+    '#SET($focus=area)'
     '[!-%s %s]' % (natexes.negation, '[{people, everyone, everybody} {overreacting, too #ONT(negative_emotion)}]'):{
         '"You\'re probably right. But honestly I don\'t blame people for being cautious. '
         'Especially if you look at Italy and China, they\'re having a rough time right now. '
         'Nobody wants to end up in that situation."': 'ur'
     },
 
+    '#SET($focus=area)'
     '[!-%s [{all, everyone, everybody, we, were}, {die, doomed, screwed, dead, fucked}]]' % natexes.negation:{
         '"Oh come on, it\'ll be okay eventually. It might be a strange next few months, but it will pass."': 'ur'
     },
@@ -258,21 +270,25 @@ user_loop = {
         '"Right."': 'ur'
     },
 
+    '#SET($focus=area)'
     '[{vaccine, cure, treatment}]':{
         '"Yeah wouldn\'t a vaccine be such a godsend?"': 'ur'
     },
 
+    '#SET($focus=area)'
     '[{lots, many, everyone, tons} {sick, ill, infected, have it, get it}]':{
         '"Yeah, it\'s scary to think about isn\'t it? '
         'The number of sick people just keeps climbing every day."': 'ur'
     },
 
+    '#SET($focus=area)'
     '[{not much, nothing} {to do, can do}]':{
         '"Right. Sometimes I think it\'s a tragic irony, '
         'how such a small organism can cause so much destruction. '
         'But people are resilient. Humanity has endured a lot worse than this."': 'ur'
     },
 
+    '#SET($focus=area)'
     '[{im, [i {am, feel, have been}]} #ONT(negative_emotion)]':{
         '"What\'s happening right now is pretty scary, it feels a little surreal. '
         'But remember that the chance of the virus affecting your '
@@ -285,6 +301,10 @@ user_loop = {
 cv.load_transitions(system_loop, ChatFlow.Speaker.SYSTEM)
 cv.load_transitions(user_loop, ChatFlow.Speaker.USER)
 
+from emora_stdm.state_transition_dialogue_manager.natex_nlu import NatexNLU
 if __name__ == '__main__':
+    natex = NatexNLU('<{} {}>'.format(natexes.negation,
+        '[{#ONTE(negative), [all, die]}]'), macros=cv._macros)
+    #print(natex.match("i really don't think that people should worry about the virus too much a lot of people have a covered from it", debugging=True))
     cv.precache_transitions()
     cv.run(debugging=True)
\ No newline at end of file
